# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/source_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/source_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/source_api.proto\x1a fsai_grpc_api/protos/utils.proto\"\x1d\n\rSourceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x0eSourceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x03\x32\x42\n\tSourceApi\x12\x35\n\x12\x46indOrCreateSource\x12\x0e.SourceRequest\x1a\x0f.SourceResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_SOURCEREQUEST = _descriptor.Descriptor(
  name='SourceRequest',
  full_name='SourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='SourceRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=104,
)


_SOURCERESPONSE = _descriptor.Descriptor(
  name='SourceResponse',
  full_name='SourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='SourceResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='SourceResponse.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=168,
)

_SOURCERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['SourceRequest'] = _SOURCEREQUEST
DESCRIPTOR.message_types_by_name['SourceResponse'] = _SOURCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SourceRequest = _reflection.GeneratedProtocolMessageType('SourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.source_api_pb2'
  # @@protoc_insertion_point(class_scope:SourceRequest)
  })
_sym_db.RegisterMessage(SourceRequest)

SourceResponse = _reflection.GeneratedProtocolMessageType('SourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SOURCERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.source_api_pb2'
  # @@protoc_insertion_point(class_scope:SourceResponse)
  })
_sym_db.RegisterMessage(SourceResponse)



_SOURCEAPI = _descriptor.ServiceDescriptor(
  name='SourceApi',
  full_name='SourceApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=170,
  serialized_end=236,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateSource',
    full_name='SourceApi.FindOrCreateSource',
    index=0,
    containing_service=None,
    input_type=_SOURCEREQUEST,
    output_type=_SOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SOURCEAPI)

DESCRIPTOR.services_by_name['SourceApi'] = _SOURCEAPI

# @@protoc_insertion_point(module_scope)
