# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/workflow_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/workflow_api.proto\x1a fsai_grpc_api/protos/utils.proto\"\x1f\n\x0fWorkflowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\n\n\x02id\x18\x02 \x01(\x03\x32J\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_WORKFLOWREQUEST = _descriptor.Descriptor(
  name='WorkflowRequest',
  full_name='WorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='WorkflowRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=108,
)


_WORKFLOWRESPONSE = _descriptor.Descriptor(
  name='WorkflowResponse',
  full_name='WorkflowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='WorkflowResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WorkflowResponse.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=174,
)

_WORKFLOWRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['WorkflowRequest'] = _WORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['WorkflowResponse'] = _WORKFLOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowRequest = _reflection.GeneratedProtocolMessageType('WorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWREQUEST,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowRequest)
  })
_sym_db.RegisterMessage(WorkflowRequest)

WorkflowResponse = _reflection.GeneratedProtocolMessageType('WorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.workflow_api_pb2'
  # @@protoc_insertion_point(class_scope:WorkflowResponse)
  })
_sym_db.RegisterMessage(WorkflowResponse)



_WORKFLOWAPI = _descriptor.ServiceDescriptor(
  name='WorkflowApi',
  full_name='WorkflowApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=176,
  serialized_end=250,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateWorkflow',
    full_name='WorkflowApi.FindOrCreateWorkflow',
    index=0,
    containing_service=None,
    input_type=_WORKFLOWREQUEST,
    output_type=_WORKFLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKFLOWAPI)

DESCRIPTOR.services_by_name['WorkflowApi'] = _WORKFLOWAPI

# @@protoc_insertion_point(module_scope)
